#!perl -T

use Test::More tests => 1;

BEGIN {
	use_ok( 'Data::Faker::JapaneseFemaleName' );
}

diag( "Testing Data::Faker::JapaneseFemaleName $Data::Faker::JapaneseFemaleName::VERSION, Perl $], $^X" );
